@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#if !defined(__JSC_H_INSIDE__) && !defined(JSC_COMPILATION) && !defined(WEBKIT2_COMPILATION)
+#if !defined(__JSC_H_INSIDE__) && !defined(BUILDING_WEBKIT)
 #error "Only <jsc/jsc.h> can be included directly."
 #endif
 
@@ -44,7 +44,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define JSC_MINOR_VERSION (38)
+#define JSC_MINOR_VERSION (40)
 
 /**
  * JSC_MICRO_VERSION:
@@ -53,7 +53,7 @@ G_BEGIN_DECLS
  * application compile time, rather than from the library linked
  * against at application run time.
  */
-#define JSC_MICRO_VERSION (3)
+#define JSC_MICRO_VERSION (1)
 
 /**
  * JSC_CHECK_VERSION:
